@@ -9,15 +9,16 @@ P  -   Safer, friendlier printf/print/sprintf + say
 
 =head1 VERSION
 
-Version  "1.1.28"
+Version  "1.1.29"
 
 =cut
 
 { package P;
 	use warnings; use strict;use mem;
-	our $VERSION='1.1.28';
+	our $VERSION='1.1.29';
 
-# RCS $Revision: 1.44 $ -  $Date: 2015-05-20 00:43:36-07 $
+# RCS $Revision: 1.45 $ -  $Date: 2015-12-14 12:09:03-08 $
+# 1.1.29  - sprintf broken: include zero-width string spec to workaround
 # 1.1.28	- testsuite fix - unknown failure case in sprintf:
 #           "Redundant argument in sprintf "... for "return sprintf $fmt, $v";
 #           Trying parens around sprintf($fmt, $v);
@@ -297,9 +298,9 @@ IGN
 										sub ($$) { $_[0] =~ m{^(?:[+-]?(?:\.[0-9]+)
 															|	(?:[0-9]+\.[0-9]+))\z}x  				&&  q{%.2f}},
 										sub ($$) { substr($_[0],0,5) eq 'HASH('			&& 
-																								'{'.sw(ellipsis).'}'	},
+																								'{'.sw(ellipsis).'}'.q{%.0s}	},
 										sub ($$) { substr($_[0],0,6) eq 'ARRAY('		&& 
-																								'['.sw(ellipsis).']'	},
+																								'['.sw(ellipsis).']'.q{%.0s}	},
 										#	sub ($$) { $mxstr && length ($_[0])>$mxstr 
 										#						&& qq("%.${mxstr}s")},
 										sub ($$) { 1																&& q{"%s"}} ];
